@@ -7,7 +7,7 @@
 
 istat <- function(x, xname) {
   if(missing(xname))
-    xname <- deparse(substitute(x))
+    xname <- short.deparse(substitute(x))
   verifyclass(x, "ppp")
   # generate simulations of CSR for use in envelopes
   simx <- envelope(x, fun=NULL, nsim=39,
