@@ -1,16 +1,21 @@
 #
 #   resolve.defaults.R
 #
-#  $Revision: 1.9 $ $Date: 2011/09/06 03:04:34 $
+#  $Revision: 1.10 $ $Date: 2012/08/21 05:21:09 $
 #
 # Resolve conflicts between several sets of defaults
 # Usage:
 #     resolve.defaults(list1, list2, list3, .......)
 # where the earlier lists have priority 
 #
-resolve.defaults <- function(..., .StripNull=FALSE) {
+resolve.defaults <- function(..., .MatchNull=TRUE, .StripNull=FALSE) {
   # Each argument is a list. Append them.
   argue <- c(...)
+  # is NULL a possible value?
+  if(!.MatchNull) {
+    isnul <- unlist(lapply(argue, is.null))
+    argue <- argue[!isnul]
+  }
   if(!is.null(nam <- names(argue))) {
     named <- nzchar(nam)
     arg.unnamed <- argue[!named]
@@ -19,6 +24,7 @@ resolve.defaults <- function(..., .StripNull=FALSE) {
       arg.named <- arg.named[!discard]
     argue <- append(arg.unnamed, arg.named)
   }
+  # should NULL become a missing argument?
   if(.StripNull) {
     isnull <- sapply(argue, is.null)
     argue <- argue[!isnull]
@@ -44,5 +50,9 @@ do.call.matched <- function(fun, arglist, funargs, extrargs=NULL) {
   do.call(fun, arglist[matched])
 }
 
-
-  
+resolve.1.default <- function(.A, ...) {
+  res <- resolve.defaults(...)
+  hit <- (names(res) == .A)
+  if(!any(hit)) return(NULL)
+  return(res[[min(which(hit))]])
+}
